==> pdfbox-3.0.2-src.zip: pdfbox-3.0.2/pdfbox/src/test/java/org/apache/pdfbox/pdmodel/interactive/documentnavigation/outline/PDOutlineItemIteratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.pdfbox.pdmodel.interactive.documentnavigation.outline;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertThrows;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

/**
 * @author Andrea Vacondio
 *
 */
class PDOutlineItemIteratorTest
{

    @Test
    void singleItem()
    {
        PDOutlineItem first = new PDOutlineItem();
        PDOutlineItemIterator iterator = new PDOutlineItemIterator(first);
        assertTrue(iterator.hasNext());
        assertEquals(first, iterator.next());
        assertFalse(iterator.hasNext());
    }

    @Test
    void multipleItem()
    {
        PDOutlineItem first = new PDOutlineItem();
        PDOutlineItem second = new PDOutlineItem();
        first.setNextSibling(second);
        PDOutlineItemIterator iterator = new PDOutlineItemIterator(first);
        assertTrue(iterator.hasNext());
        assertEquals(first, iterator.next());
        assertTrue(iterator.hasNext());
        assertEquals(second, iterator.next());
        assertFalse(iterator.hasNext());
    }

    @Test
    void removeUnsupported()
    {
        PDOutlineItemIterator pdOutlineItemIterator = new PDOutlineItemIterator(new PDOutlineItem());
        assertThrows(UnsupportedOperationException.class, () -> pdOutlineItemIterator.remove());
    }

    @Test
    void noChildren()
    {
        PDOutlineItemIterator iterator = new PDOutlineItemIterator(null);
        assertFalse(iterator.hasNext());
    }
}

==> pdfbox-3.0.6-src.zip: pdfbox-3.0.6/pdfbox/src/test/java/org/apache/pdfbox/pdmodel/interactive/documentnavigation/outline/PDOutlineItemIteratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.pdfbox.pdmodel.interactive.documentnavigation.outline;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertThrows;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

/**
 * @author Andrea Vacondio
 *
 */
class PDOutlineItemIteratorTest
{

    @Test
    void singleItem()
    {
        PDOutlineItem first = new PDOutlineItem();
        PDOutlineItemIterator iterator = new PDOutlineItemIterator(first);
        assertTrue(iterator.hasNext());
        assertEquals(first, iterator.next());
        assertFalse(iterator.hasNext());
    }

    @Test
    void multipleItem()
    {
        PDOutlineItem first = new PDOutlineItem();
        PDOutlineItem second = new PDOutlineItem();
        first.setNextSibling(second);
        PDOutlineItemIterator iterator = new PDOutlineItemIterator(first);
        assertTrue(iterator.hasNext());
        assertEquals(first, iterator.next());
        assertTrue(iterator.hasNext());
        assertEquals(second, iterator.next());
        assertFalse(iterator.hasNext());
    }

    @Test
    void removeUnsupported()
    {
        PDOutlineItemIterator pdOutlineItemIterator = new PDOutlineItemIterator(new PDOutlineItem());
        assertThrows(UnsupportedOperationException.class, pdOutlineItemIterator::remove);
    }

    @Test
    void noChildren()
    {
        PDOutlineItemIterator iterator = new PDOutlineItemIterator(null);
        assertFalse(iterator.hasNext());
    }
}
